pub struct AuxInfoBuilder<'a, L, D = Sha256>where
L: SecurityLevel,
D: Digest,{ /* private fields */ }Expand description
Entry point for key refresh and auxiliary info generation.
Implementations
Sourceimpl<'a, L, D> AuxInfoBuilder<'a, L, D>where
L: SecurityLevel,
D: Digest,
impl<'a, L, D> AuxInfoBuilder<'a, L, D>where
L: SecurityLevel,
D: Digest,
Sourcepub fn new_aux_gen(
eid: ExecutionId<'a>,
i: u16,
n: u16,
pregenerated: PregeneratedPrimes<L>,
) -> Self
pub fn new_aux_gen( eid: ExecutionId<'a>, i: u16, n: u16, pregenerated: PregeneratedPrimes<L>, ) -> Self
Build key aux info generation operation. Start it with start.
PregeneratedPrimes can be obtained with PregeneratedPrimes::generate
Sourcepub async fn start<R, M>(
self,
rng: &mut R,
party: M,
) -> Result<AuxInfo<L>, KeyRefreshError>where
R: RngCore + CryptoRng,
M: Mpc<ProtocolMessage = Msg<D, L>>,
L: SecurityLevel,
D: Digest + Clone + 'static,
pub async fn start<R, M>(
self,
rng: &mut R,
party: M,
) -> Result<AuxInfo<L>, KeyRefreshError>where
R: RngCore + CryptoRng,
M: Mpc<ProtocolMessage = Msg<D, L>>,
L: SecurityLevel,
D: Digest + Clone + 'static,
Carry out the aux info generation procedure. Takes a lot of time
Sourcepub fn into_state_machine<R>(
self,
rng: &'a mut R,
) -> impl StateMachine<Output = Result<AuxInfo<L>, KeyRefreshError>, Msg = Msg<D, L>> + 'a
Available on crate feature state-machine only.
pub fn into_state_machine<R>( self, rng: &'a mut R, ) -> impl StateMachine<Output = Result<AuxInfo<L>, KeyRefreshError>, Msg = Msg<D, L>> + 'a
state-machine only.Returns a state machine that can be used to carry out the aux info generation protocol
See [round_based::state_machine] for details on how that can be done.
Sourceimpl<'a, L, D> AuxInfoBuilder<'a, L, D>where
L: SecurityLevel,
D: Digest,
impl<'a, L, D> AuxInfoBuilder<'a, L, D>where
L: SecurityLevel,
D: Digest,
Sourcepub fn set_digest<D2: Digest>(self) -> AuxInfoBuilder<'a, L, D2>
pub fn set_digest<D2: Digest>(self) -> AuxInfoBuilder<'a, L, D2>
Specifies another hash function to use
Sourcepub fn set_progress_tracer(self, tracer: &'a mut dyn Tracer) -> Self
pub fn set_progress_tracer(self, tracer: &'a mut dyn Tracer) -> Self
Sets a tracer that tracks progress of protocol execution
Sourcepub fn enforce_reliable_broadcast(self, v: bool) -> Self
pub fn enforce_reliable_broadcast(self, v: bool) -> Self
Ensures reliability of broadcast channel by adding one extra communication round
CGGMP24 protocol requires message in the first round to be sent over reliable broadcast channel. We ensure reliability of the broadcast channel by introducing extra communication round (at cost of additional latency). You may disable it, for instance, if your transport layer is reliable by construction (e.g. you use blockchain for communications).
Default: true.
Sourcepub fn precompute_multiexp_tables(self, v: bool) -> Self
pub fn precompute_multiexp_tables(self, v: bool) -> Self
Precomputes multiexponentiation tables for output aux data
Enables optimization that makes signing and presigning faster. Precomputation takes a while and makes protocol a bit longer. It noticebly increases size of aux data both in RAM and on disk (after serialization).